/*******************************************************************************
*    Robot "Giskard" 1.0.                                                      *
*    Copyright (C) 2009 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    Circuits  by Marian Neubert     marian@tesla-crew.de                      *
*    Mechanism by Mario Zimmermann   mario@tesla-crew.de                       *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; version 2 of the License.                   *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

#include <stdlib.h>
#include <string.h>
#include <avr/interrupt.h>
#include <avr/wdt.h>
#include "inc/giskard.h"
#include "inc/leds.h"
#include "inc/tools.h"
#include "inc/voice.h"
#include "inc/twislave.h"

extern volatile uint8_t rxbuffer[buffer_size], txbuffer[buffer_size], buffer_adr;

int main(void)
{
  int l;

  // Watchdog deaktivieren
  MCUCSR = 0;
  wdt_disable();

  // ATMEGA_SIGNAL, ATMEGA_DATA und ATMEGA_CMDRUN als OUTPUT
  ATMEGA_DDR |= (1<<ATMEGA_SIGNAL) | (1<<ATMEGA_DATA) | (1<<ATMEGA_CMDRUN);
  // Alles auf 0 setzen, so daß kein falsches Signal geschickt wird
  ATMEGA_PORT &= ~(1<<ATMEGA_SIGNAL);
  ATMEGA_PORT &= ~(1<<ATMEGA_DATA);

  // ATMEGA_ACK als INPUT
  ATMEGA_DDR &= ~(1<<ATMEGA_ACK);

  for(l = 0; l < buffer_size; l++)
    rxbuffer[l] = txbuffer[l] = 0;
  buffer_adr = 0;
  doInitLEDs();
  doInitTimer();
  init_twi_slave(MYI2C);
  doInitVoice();

  sendReadySignal();
  while(1 == 1)
  {
    ATMEGA_PORT &= ~(1<<ATMEGA_SIGNAL);
    ATMEGA_PORT &= ~(1<<ATMEGA_DATA);

    if((getUptime() % 1000) == 0)
      turnOnLED(LED1);
    if(((getUptime() - 300) % 1000) == 0)
    {
      turnOffLED(LED1);
      turnOffExtraLED(LED1);
    }

    if(rxbuffer[0] == CMD_RESET)
    {
      gotCommand();
      resetMicro();
    }
    if(rxbuffer[0] == CMD_GETPRGVERSION)
    {
      sendVersionNr();
      gotCommand();
    }
    if(rxbuffer[0] == CMD_LEARN)
    {
      sendToVoiceDirect(VD_CMD_LEARN);
      gotCommand();
    }
    if(rxbuffer[0] == CMD_HEAR)
    {
      sendToVoiceDirect(VD_CMD_HEAR);
      gotCommand();
    }
    if(rxbuffer[0] == CMD_HEAR_PROMPT)
    {
      sendToVoiceDirect(VD_CMD_HEAR_PROMPT);
      gotCommand();
    }
    if(rxbuffer[0] == CMD_DELETEDICT)
    {
      sendToVoiceDirect(VD_CMD_DELETEDICT);
      gotCommand();
    }
    if(rxbuffer[0] == CMD_GETVERSION)
    {
      sendToVoiceDirect(VD_CMD_GETVERSION);
      gotCommand();
    }
    if(rxbuffer[0] == CMD_GETALLVERSION)
    {
      sendToVoiceDirect(VD_CMD_GETALLVERSION);
      gotCommand();
    }

    buffer_adr = 0;
    doLoopJobsVoice();
  }
  return(0);
}

/**
 * Schickt die Versionsnummer des Programms
 */
void sendVersionNr()
{
  uint8_t l, p;
  char v[50];

  strcpy(v, VERSIONSTRING);
  txbuffer[0] = ATMEGAANSWER_OTHER;
  for(p = 2, l = 0; l < strlen(v); l++)
    txbuffer[p++] = v[l];
  txbuffer[1] = p - 2;
  buffer_adr = 0;
  ATMEGA_PORT |= (1<<ATMEGA_SIGNAL) | (1<<ATMEGA_DATA);
  waitForACK();
}
