/*******************************************************************************
*    Robot "Giskard" 1.0.                                                      *
*    Copyright (C) 2009 Luca Bertoncello                                       *
*    Hartigstrasse, 12 - 01127 Dresden Deutschland                             *
*    E-Mail: lucabert@lucabert.de, lucabert@lucabert.com                       *
*    http://www.lucabert.de/  http://www.lucabert.com/                         *
*                                                                              *
*    Circuits  by Marian Neubert     marian@tesla-crew.de                      *
*    Mechanism by Mario Zimmermann   mario@tesla-crew.de                       *
*                                                                              *
*    This program is free software; you can redistribute it and/or modify      *
*    it under the terms of the GNU General Public License as published by      *
*    the Free Software Foundation; version 2 of the License.                   *
*                                                                              *
*    This program is distributed in the hope that it will be useful,           *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*    GNU General Public License for more details.                              *
*                                                                              *
*    You should have received a copy of the GNU General Public License         *
*    along with this program; if not, write to the Free Software               *
*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA *
*******************************************************************************/

#ifndef GISKARD_H_
#define GISKARD_H_

#define VERSIONSTRING  "1.0RC3 Build 20100807"

#define MYI2C                 0xD0
#define STATUSREGISTER        0
#define WORDREGISTER          1

#define boolean               uint8_t
#define TRUE                  1
#define FALSE                 0

#define CMD_LEARN               'L'
#define CMD_HEAR                'H'
#define CMD_HEAR_PROMPT         'P'
#define CMD_DELETEDICT          'D'
#define CMD_GETVERSION          'V'
#define CMD_RESET               'R'
#define CMD_GETPRGVERSION       'v'
#define CMD_GETALLVERSION       'A'

#define LED_DDR                 DDRD
#define LED_PORT                PORTD
#define LED_PIN                 PIND
#define LED1_PIN                0  // PIND0
#define LED2_PIN                1  // PIND1
#define LED3_PIN                2  // PIND2
#define LED4_PIN                4  // PIND4
#define LED1                    1
#define LED2                    2
#define LED3                    4
#define LED4                    16

#define EXTRALED_DDR            DDRB
#define EXTRALED_PORT           PORTB
#define EXTRALED_PIN            PINB
#define EXTRALED1_PIN           0  // PINB0

// Verbindung mit dem ATMega128
#define ATMEGA_DDR              DDRD
#define ATMEGA_PORT             PORTD
#define ATMEGA_PIN              PIND
#define ATMEGA_CMDRUN           2 // PORTD2
#define ATMEGA_SIGNAL           5 // PORTD5
#define ATMEGA_DATA             6 // PORTD6
#define ATMEGA_ACK              7 // PORTD7

// Verbidung mit dem VoiceDirect364
#define VD_DDR_MHS              DDRC
#define VD_PORT_MHS             PORTC
#define VD_PIN_MHS              PINC

#define VD_DDR_DATA             DDRC
#define VD_PORT_DATA            PORTC
#define VD_PIN_DATA             PINC

#define VD_DDR_SHS              DDRC
#define VD_PORT_SHS             PORTC
#define VD_PIN_SHS              PINC

#define VD_DDR_BSY              DDRB
#define VD_PORT_BSY             PORTB
#define VD_PIN_BSY              PINB

#define VD_DDR_RST              DDRB
#define VD_PORT_RST             PORTB
#define VD_PIN_RST              PINB

#define VD_MHS                  2  // PORTC2
#define VD_SHS                  1  // PORTC1
#define VD_DATA                 0  // PORTC0
#define VD_BSY                  2  // PINB2
#define VD_RST                  1  // PINB1

/**
 * Das Befehl wurde angenommen
 * Löscht die erste zwei Bytes (Typ und Länge)
 */
#define gotCommand()            { rxbuffer[0] = 0; rxbuffer[1] = 0; turnOnExtraLED(LED1); }

/**
 * Reset den Mikrocontroller (über Watchdog)
 */
#define resetMicro()            { \
                                  do \
                                  { \
                                    wdt_enable(WDTO_15MS); \
                                    for(;;); \
                                  } while(0); \
                                }

/**
 * Schickt die Versionsnummer des Programms
 */
void sendVersionNr(void);

#endif /* GISKARD_H_ */
